@@ -10,8 +10,8 @@ import pandas as pd
 from .eclfiles import EclFiles
 from .common import (
     merge_zones,
-    parse_opmio_deckrecord,
     parse_opmio_date_rec,
+    parse_opmio_deckrecord,
     parse_opmio_tstep_rec,
     write_dframe_stdout_file,
 )
@@ -42,6 +42,12 @@ COMPDAT_RENAMER = {
     "PR": "PEQVR",
 }
 
+# Workaround an inconsistency in JSON-files for OPM-common < 2021.04:
+WSEG_RENAMER = {
+    "SEG1": "SEGMENT1",
+    "SEG2": "SEGMENT2",
+}
+
 
 def deck2dfs(deck, start_date=None, unroll=True):
     """Loop through the deck and pick up information found
@@ -118,13 +124,13 @@ def deck2dfs(deck, start_date=None, unroll=True):
                 compdatrecords.append(rec_data)
         elif kword.name == "WSEGSICD":
             for rec in kword:  # Loop over the lines inside WSEGSICD record
-                rec_data = parse_opmio_deckrecord(rec, "WSEGSICD")
+                rec_data = parse_opmio_deckrecord(rec, "WSEGSICD", renamer=WSEG_RENAMER)
                 rec_data["DATE"] = date
                 rec_data["KEYWORD_IDX"] = idx
                 wsegsicdrecords.append(rec_data)
         elif kword.name == "WSEGAICD":
             for rec in kword:  # Loop over the lines inside WSEGAICD record
-                rec_data = parse_opmio_deckrecord(rec, "WSEGAICD")
+                rec_data = parse_opmio_deckrecord(rec, "WSEGAICD", renamer=WSEG_RENAMER)
                 rec_data["DATE"] = date
                 rec_data["KEYWORD_IDX"] = idx
                 wsegaicdrecords.append(rec_data)
