@@ -1,14 +1,8 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 End-user command line tool for accessing functionality
 in ecl2df
 """
-
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
-
 import sys
 
 import argparse
@@ -32,6 +26,14 @@ from ecl2df import (
 
 from ecl2df import __version__
 
+# String constants in use for generating ERT forward model documentation:
+DESCRIPTION = """Convert Eclipse input and output files into CSV files.
+Uses the command line utility ``ecl2csv``. Run ``ecl2csv --help`` to see
+which subcommands are supported. It is not possible to supply extra
+options to ecl2csv through this forward model."""
+CATEGORY = "utility.eclipse"
+EXAMPLES = "``FORWARD_MODEL ECL2CSV(<SUBCOMMAND>=equil, <OUTPUT>=equil.csv)``"
+
 
 def get_parser():
     """Make parser"""
