@@ -1,11 +1,7 @@
 """Test module for equil2df"""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-import os
 import sys
+from pathlib import Path
 
 import pytest
 
@@ -14,8 +10,8 @@ import pandas as pd
 from ecl2df import equil, ecl2csv
 from ecl2df.eclfiles import EclFiles
 
-TESTDIR = os.path.dirname(os.path.abspath(__file__))
-DATAFILE = os.path.join(TESTDIR, "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+TESTDIR = Path(__file__).absolute().parent
+DATAFILE = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
 
 
 def test_equil2df():
@@ -44,11 +40,11 @@ def test_df2ecl(tmpdir):
     eclfiles = EclFiles(DATAFILE)
     equildf = equil.df(eclfiles)
     equil.df2ecl(equildf, filename="equil.inc")
-    assert os.path.exists("equil.inc")
+    assert Path("equil.inc").is_file()
 
     # Test automatic directory creation:
     equil.df2ecl(equildf, filename="eclipse/include/equil.inc")
-    assert os.path.exists("eclipse/include/equil.inc")
+    assert Path("eclipse/include/equil.inc").is_file()
 
 
 def test_decks():
@@ -326,7 +322,7 @@ EQUIL
     assert df["EQLNUM"].min() == 1
     assert df["EQLNUM"].max() == 2
     # Supply correct NTEQUL instead of estimating
-    df = equil.deck2df(deckstr, 2)
+    df = equil.df(deckstr, ntequl=2)
     assert len(df) == 2
 
     inc = equil.df2ecl(df, withphases=True)
@@ -334,12 +330,12 @@ EQUIL
     pd.testing.assert_frame_equal(df, df_from_inc, check_dtype=False)
 
     # Supplying wrong NTEQUIL:
-    df = equil.deck2df(deckstr, 1)
+    df = equil.df(deckstr, ntequl=1)
     # We are not able to catch this situation..
     assert len(df) == 1
     # But this will fail:
     with pytest.raises(ValueError):
-        equil.deck2df(deckstr, 3)
+        equil.df(deckstr, ntequl=3)
 
     deckstr = """
 GAS
@@ -361,23 +357,12 @@ EQUIL
     pd.testing.assert_frame_equal(df, df_from_inc, check_dtype=False)
 
 
-def test_main(tmpdir):
-    """Test command line interface"""
-    tmpcsvfile = tmpdir.join(".TMP-equil.csv")
-    sys.argv = ["equil2csv", DATAFILE, "-o", str(tmpcsvfile)]
-    equil.main()
-
-    assert os.path.exists(str(tmpcsvfile))
-    disk_df = pd.read_csv(str(tmpcsvfile))
-    assert not disk_df.empty
-
-
 def test_main_subparser(tmpdir):
     """Test command line interface"""
-    tmpcsvfile = tmpdir.join(".TMP-equil.csv")
+    tmpcsvfile = tmpdir / ".TMP-equil.csv"
     sys.argv = ["ecl2csv", "equil", "-v", DATAFILE, "-o", str(tmpcsvfile)]
     ecl2csv.main()
 
-    assert os.path.exists(str(tmpcsvfile))
+    assert Path(tmpcsvfile).is_file()
     disk_df = pd.read_csv(str(tmpcsvfile))
     assert not disk_df.empty
