@@ -1,12 +1,8 @@
 """Test module for ecl2df.grid"""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-import os
 import sys
 import datetime
+from pathlib import Path
 
 import numpy as np
 import pandas as pd
@@ -17,8 +13,8 @@ from ecl2df import grid
 from ecl2df import ecl2csv
 from ecl2df.eclfiles import EclFiles
 
-TESTDIR = os.path.dirname(os.path.abspath(__file__))
-DATAFILE = os.path.join(TESTDIR, "data/reek/eclipse/model/2_R001_REEK-0.DATA")
+TESTDIR = Path(__file__).absolute().parent
+DATAFILE = str(TESTDIR / "data/reek/eclipse/model/2_R001_REEK-0.DATA")
 
 
 def test_gridgeometry2df():
@@ -46,10 +42,6 @@ def test_gridgeometry2df():
 def test_wrongfile():
     """Test the EclFiles object on nonexistent files"""
     # pylint: disable=invalid-name,redefined-builtin
-    try:
-        FileNotFoundError
-    except NameError:
-        FileNotFoundError = IOError
 
     # We can initalize this object with bogus:
     eclfiles = EclFiles("FOO.DATA")
@@ -137,7 +129,7 @@ def test_df2ecl(tmpdir):
 
     tmpdir.chdir()
     grid.df2ecl(grid_df, ["PERMX", "PERMY", "PERMZ"], dtype=float, filename="perm.inc")
-    assert os.path.exists("perm.inc")
+    assert Path("perm.inc").is_file()
     incstring = open("perm.inc").readlines()
     assert sum([1 for line in incstring if "PERM" in line]) == 6
 
@@ -158,8 +150,10 @@ def test_df2ecl(tmpdir):
 
 def test_df2ecl_mock():
     """Test that we can use df2ecl for mocked minimal dataframes"""
-    gr = pd.DataFrame(columns=["FIPNUM"], data=[[1], [2], [3]])
-    simple_fipnum_inc = grid.df2ecl(gr, keywords="FIPNUM", dtype=int, nocomments=True)
+    a_grid = pd.DataFrame(columns=["FIPNUM"], data=[[1], [2], [3]])
+    simple_fipnum_inc = grid.df2ecl(
+        a_grid, keywords="FIPNUM", dtype=int, nocomments=True
+    )
     # (A warning is printed, that warning is warranted)
     assert "FIPNUM" in simple_fipnum_inc
     assert len(simple_fipnum_inc.replace("\n", " ").split()) == 5
@@ -281,7 +275,7 @@ def test_df():
 
 def test_main(tmpdir):
     """Test command line interface"""
-    tmpcsvfile = tmpdir.join(".TMP-eclgrid.csv")
+    tmpcsvfile = tmpdir / "eclgrid.csv"
     sys.argv = [
         "ecl2csv",
         "grid",
@@ -290,14 +284,14 @@ def test_main(tmpdir):
         str(tmpcsvfile),
         "--rstdates",
         "first",
-        "--init",
+        "--vectors",
         "PORO",
     ]
     ecl2csv.main()
-    assert os.path.exists(str(tmpcsvfile))
+    assert Path(tmpcsvfile).is_file()
     disk_df = pd.read_csv(str(tmpcsvfile))
     assert not disk_df.empty
-    os.remove(str(tmpcsvfile))
+    Path(tmpcsvfile).unlink()
 
     # Do again with also restarts:
     sys.argv = [
@@ -308,19 +302,19 @@ def test_main(tmpdir):
         str(tmpcsvfile),
         "--rstdates",
         "2001-02-01",
-        "--init",
+        "--vectors",
         "PORO",
     ]
     ecl2csv.main()
-    assert os.path.exists(str(tmpcsvfile))
+    assert Path(tmpcsvfile).is_file()
     disk_df = pd.read_csv(str(tmpcsvfile))
     assert not disk_df.empty
-    os.remove(str(tmpcsvfile))
+    Path(tmpcsvfile).unlink()
 
     # Test with constants dropping
     sys.argv = ["ecl2csv", "grid", DATAFILE, "-o", str(tmpcsvfile), "--dropconstants"]
     ecl2csv.main()
-    assert os.path.exists(str(tmpcsvfile))
+    assert Path(tmpcsvfile).is_file()
     disk_df = pd.read_csv(str(tmpcsvfile))
     # That PVTNUM is constant is a particular feature
     # of the test dataset.
@@ -328,12 +322,12 @@ def test_main(tmpdir):
     assert not disk_df.empty
 
 
-def test_rstdates():
+def test_get_available_rst_dates():
     """Test the support of dates in restart files"""
     eclfiles = EclFiles(DATAFILE)
     # rstfile = eclfiles.get_rstfile()
 
-    alldates = grid.rstdates(eclfiles)
+    alldates = grid.get_available_rst_dates(eclfiles)
     assert len(alldates) == 4
 
     didx = grid.dates2rstindices(eclfiles, "all")
@@ -350,7 +344,7 @@ def test_rstdates():
     last = grid.dates2rstindices(eclfiles, "last")
     assert last[1][0] == alldates[-1]
 
-    dates = grid.rstdates(eclfiles)
+    dates = grid.get_available_rst_dates(eclfiles)
     assert isinstance(dates, list)
 
     # Test with missing RST file:
@@ -375,7 +369,7 @@ def test_rst2df():
     assert "DATE" in rst_df
     assert rst_df["DATE"].unique()[0] == "2000-01-01"
     rst_df = grid.rst2df(eclfiles, "all", stackdates=True)
-    assert len(rst_df["DATE"].unique()) == len(grid.rstdates(eclfiles))
+    assert len(rst_df["DATE"].unique()) == len(grid.get_available_rst_dates(eclfiles))
     assert rst_df.shape == (4 * 35817, 23 + 1)  # "DATE" is now the extra column
 
     # Check vector slicing:
